Compound Visual Test : Accordion in Tabs

- First
- Second

### Accordion Header 1

Accordion Content 1

Accordion Content 1

Accordion Content 1

Accordion Content 1

Accordion Content 1

### Accordion Header 2

Accordion Content 2

Accordion Content 2

Accordion Content 2

Accordion Content 2

Accordion Content 2

### Accordion Header 3

Accordion Content 3

Accordion Content 3

Accordion Content 3

Accordion Content 3

Accordion Content 3

### Accordion Header 1

Accordion Content 1

Accordion Content 1

Accordion Content 1

Accordion Content 1

Accordion Content 1

### Accordion Header 2

Accordion Content 2

Accordion Content 2

Accordion Content 2

Accordion Content 2

Accordion Content 2

### Accordion Header 3

Accordion Content 3

Accordion Content 3

Accordion Content 3

Accordion Content 3

Accordion Content 3